====================================
Attax: adversarial attacks using JAX
====================================

Attax is python library with implementations of some common adversarial attacks
using JAX. For now this is a prototype at best and I refer you my other project,
`Foolbox <https://github.com/bethgelab/foolbox>`_, that also supports JAX and
provides a well-tested suite of adversarial attacks.

